==> hindent-5.3.1-40-x86_64.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.3.1
id: hindent-5.3.1-8SRcDrLuUj6HHeAzx8QXli
key: hindent-5.3.1-8SRcDrLuUj6HHeAzx8QXli
license: BSD-3-Clause
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
abi: a4e4fc838df2a1a4588642ffc84bbf4b
exposed: True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.CodeBlock HIndent.Pretty
    HIndent.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.3.1-8SRcDrLuUj6HHeAzx8QXli
depends:
    Cabal-2.4.0.1 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.3-C2fkKAVjk4AA6i9Cl1i116
    filepath-1.4.2.1 haskell-src-exts-1.21.1-Knj2Sf32FhF4mJrXgorIEK
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2 text-1.2.3.1
    transformers-0.5.6.2 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    yaml-0.11.2.0-alxzflql864nfC2SW5pb6
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-5.3.1-41-x86_64.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.3.1
id: hindent-5.3.1-15QbSN27TdS3CFna3FQg54
key: hindent-5.3.1-15QbSN27TdS3CFna3FQg54
license: BSD-3-Clause
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
abi: 15e17ca14c469b0ece18a041110af0d0
exposed: True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.CodeBlock HIndent.Pretty
    HIndent.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.3.1-15QbSN27TdS3CFna3FQg54
depends:
    Cabal-2.4.0.1 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.3-C2fkKAVjk4AA6i9Cl1i116
    filepath-1.4.2.1 haskell-src-exts-1.21.1-Knj2Sf32FhF4mJrXgorIEK
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2 text-1.2.3.1
    transformers-0.5.6.2 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    yaml-0.11.2.0-kwMBXLDeksBUKCXUxlQ5
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
